#!/bin/sh

ver=`sed -n -e 's/^.*Revision: //p' /REVISION`
wanted="37956"

if [ "$ver" != "$wanted" ] ; then
    echo "Your firmware version $ver is not compatible with this patch"
    echo "Installation cannot continue"
    echo "This patch requires firmware version simply8654t2_trunk_37956-1_201108211726.bin"
    exit
fi

if [ ! -f /tmp/3pimp.tgz ] ; then
    echo update not found - exiting
    exit
fi

if [ "$(/sbin/setxenv2 -f /dev/sigmblocka -k z.allow_telnet | cut -d' ' -f4)" != "0x00000001" ] ; then
   echo "enabling telnet in the rescue system"
   /sbin/setxenv2 -f /dev/sigmblocka -k z.allow_telnet -v 0x00000001
fi

echo remounting / rw
/sbin/fsck.jfs /dev/sda5
mount -o remount,rw /dev/sda5 /

echo making backups of system files
if [ ! -f /etc/rc.d/rcS.orig ] ; then
    cp /etc/rc.d/rcS /etc/rc.d/rcS.orig
fi
if [ ! -f /etc/passwd.orig ] ; then
    cp /etc/passwd /etc/passwd.orig
fi
if [ ! -f /avtrex/bin/sigma8654_CCESonyMax_backend.orig ] ; then
    cp /avtrex/bin/sigma8654_CCESonyMax_backend /avtrex/bin/sigma8654_CCESonyMax_backend.orig
fi
if [ ! -f /avtrex/bin/sgtv.propbin.orig ] ; then
    cp /avtrex/bin/sgtv.propbin /avtrex/bin/sgtv.propbin.orig
fi

echo installing...
cd /
tar -C / -xzf /tmp/3pimp.tgz

cd /tmp

echo applying binary patches 

if [ ! -f /avtrex/bin/sigma8654_CCESonyMax_backend.noscan ] ; then
    cp /avtrex/bin/sigma8654_CCESonyMax_backend /avtrex/bin/sigma8654_CCESonyMax_backend.noscan
    printf "\x20\x75\x6e" | dd of=/avtrex/bin/sigma8654_CCESonyMax_backend.noscan bs=1 seek=20115182 conv=notrunc
fi

if [ ! -f /avtrex/bin/epg.propbin ] ; then
    cp /avtrex/bin/sgtv.propbin /avtrex/bin/epg.propbin
    printf "\x4e\x6f\x72\x6d\x61\x6c\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52" | dd of=/avtrex/bin/sgtv.propbin bs=1 seek=382551 conv=notrunc
    printf "\x4e\x6f\x72\x6d\x61\x6c\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52" | dd of=/avtrex/bin/sgtv.propbin bs=1 seek=1024302 conv=notrunc
    printf "\x45\x50\x47\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52\x2e\x2e\x2e" | dd of=/avtrex/bin/epg.propbin bs=1 seek=382551 conv=notrunc
    printf "\x45\x50\x47\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52\x2e\x2e\x2e" | dd of=/avtrex/bin/epg.propbin bs=1 seek=1024302 conv=notrunc
fi

printf "\x31\x32\x37\x2E\x30\x2E\x30\x2E\x31\x2F\x73\x65\x74\x74\x69\x6E\x67\x73\x2F\x63\x6F\x64\x67\x65\x2F\x76\x61\x72\x2F\x77\x77\x77\x2F\x72\x65\x64\x69\x72\x65\x63\x74\x6F\x72" | dd of=/avtrex/bin/sgtv.propbin bs=1 seek=38901 conv=notrunc

printf "\x31\x32\x37\x2E\x30\x2E\x30\x2E\x31\x2F\x73\x65\x74\x74\x69\x6E\x67\x73\x2F\x63\x6F\x64\x67\x65\x2F\x76\x61\x72\x2F\x77\x77\x77\x2F\x72\x65\x64\x69\x72\x65\x63\x74\x6F\x72" | dd of=/avtrex/bin/epg.propbin bs=1 seek=38901 conv=notrunc

if [ -f /etc/rc.d/rcS.scan ] ; then
    echo removing old patch files...
    rm -f /etc/rc.d/rcS.scan
    rm -f /etc/rc.d/rcS.noscan
    rm -rf /home/cron
    rm -f /sbin/buttonhook
    rm -f /sbin/ssh-keygen
    rm -f /sbin/sshd
    rm -f /usr/bin/crontab
    rm -f /usr/bin/ssmtp
    rm -f /usr/bin/ssmtp-config
    rm -f /usr/libexec/sftp-server
    rm -rf /usr/local/etc
    rm -f /usr/sbin/cron
    rm -f /bin/noscanboot
    rm -f /bin/rsync
    rm -f /bin/scanboot
    rm -f /bin/scp
    rm -f /bin/sftp
    rm -f /bin/ssh
    rm -f /bin/ssh-add
    rm -f /bin/ssh-agent
    rm -rf /var/empty
    if [ -f /avtrex/bin/files/argent/avtrex_splash.png.orig ] ; then
        mv /avtrex/bin/files/argent/avtrex_splash.png.orig /avtrex/bin/files/argent/avtrex_splash.png
        rm -f /avtrex/bin/files/argent/avtrex_splash-EPG.png
        rm -f /avtrex/bin/files/argent/avtrex_splash-normal.png
    fi
fi 

echo mounting / ro
echo "if you see an error here, that's OK"
mount -o remount,ro /dev/sda5 /

if [ ! -d /home/3view/backup/channels ] ; then
    mkdir -p /home/3view/backup/channels
fi

if [ ! -d /home/3view/backup/database ] ; then
    mkdir -p /home/3view/backup/database
fi

echo creating database backup
/settings/codge/bin/rsync -a --no-owner --no-perms /settings/db/ /home/3view/backup/database

echo creating channels backup
/settings/codge/bin/backupchannels

echo completed, please type reboot now to finish installation.

